@@ -70,6 +70,8 @@ Later updates (from the source web site):
 
 =item * version 0.92, published on September 18, 2006
 
+=item * version 0.97, published on October 23, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -115,3 +117,4 @@ amber_dextrous stinky_pete
 phil_o_dendron
 steve
 lyin_john
+mindy
