@@ -48,6 +48,8 @@ Further updates:
 
 =item * version 0.96, published on October 16, 2006
 
+=item * version 0.97, published on October 23, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -308,6 +310,7 @@ ANFI
 ANGUSLEES
 ANGUYEN
 ANH
+ANIAS
 ANIMATOR
 ANIO
 ANK
@@ -622,6 +625,7 @@ BKRAMER
 BKUHN
 BLABES
 BLACKSTAR
+BLADE
 BLAIR
 BLANTREWI
 BLBLACK
@@ -664,6 +668,7 @@ BOCONNOR
 BODIN
 BOESCH
 BOEWE
+BOGA
 BOLEK
 BONAR
 BONDFOG
@@ -1540,6 +1545,7 @@ EJS
 EKG
 EKMETT
 ELAGACHE
+ELENAFRIE
 ELEONORA
 ELEPHANT
 ELH
@@ -1568,6 +1574,7 @@ ENEGAARD
 ENELL
 ENGELS
 ENGIN
+ENHERING
 ENNO
 ENRYS
 EPSALON
@@ -2199,6 +2206,7 @@ IZUT
 JAAN
 JABLKO
 JABURO
+JACKB
 JACKS
 JACKSONM
 JACKTAO
@@ -2969,6 +2977,7 @@ LBENDAVID
 LBORGMAN
 LBOTTEL
 LBROCARD
+LCHAVEZ
 LCOWLE
 LDACHARY
 LDOMKE
@@ -3183,6 +3192,7 @@ MARKWIN
 MARMS
 MARNANEL
 MARSHALL
+MARTIAN
 MARTIJN
 MARTIN
 MARTINB
@@ -3398,6 +3408,7 @@ MIRROROK
 MISAKA
 MISCHKE
 MISHA
+MISHOO
 MIT
 MITEL
 MITREHC
@@ -3493,6 +3504,7 @@ MORNI
 MORRISNIH
 MORTENF
 MORTY
+MOSSAD
 MOSTAFAVI
 MOTT
 MOUNS
@@ -4007,6 +4019,7 @@ PMC
 PMEVZEK
 PMH
 PMICHAUD
+PMINT
 PMISON
 PMKANE
 PMOORE
@@ -4296,6 +4309,7 @@ RLB
 RLBJR
 RLGARRIS
 RLOCKE
+RLUCAS
 RLZWART
 RMALAFAIA
 RMANGI
@@ -4573,6 +4587,7 @@ SEZAY
 SFARRELL
 SFI
 SFINK
+SFLEX
 SFRESCHI
 SGEL
 SGMIANO
@@ -4881,6 +4896,7 @@ SUDIP
 SUE
 SUJAI
 SULFERIC
+SULLIVAN
 SULLR
 SUMMER
 SUMPFRALL
@@ -5029,6 +5045,7 @@ THUNDERA
 THUNDERS
 THW
 TIBBS
+TIGERPERL
 TIGRIS
 TILLY
 TIMA
@@ -5459,6 +5476,7 @@ ZAG
 ZAKZ
 ZANGHIHU
 ZAPHAR
+ZAPHER
 ZARQUON
 ZAXO
 ZBODI
